app

package
v0.0.0-...-1c033b4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2024 License: GPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	TARGET    string
	IGNORE    []string
	GIT_REPOS []gitInfo
)

Functions

func Main

func Main(target string, ignore []string)

takes a string [target] and searches for git repos within the specified path. Generates and outputs a report of the status of found git repositories.

Types

This section is empty.

Jump to